/***************************************************************************
                          inifile.cpp  -  description
                             -------------------
begin		: Dec 05 2003
copyright	: (C) 2002 by Bastiaan Naber, (C) 2002 by Robert Wittams
email		: bastiaan@ricardis.tudelft.nl
description	: This class takes a QString filename of an ini-file and
		  reads it in. The ini file should be in the format:
		  # This is a comment
		
		  [section1]
		  name1=argument1
		  name2=argument2
			   
		  [section2]
		  name1=argument1
		  name2=argument2
		   
		  Each section is put into a IniSection object and a 
		  pointer to the IniSection object is retrieved by 
		  getSection("section1")
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <stdlib.h>

#include <qfile.h>
#include <iostream>
using namespace std;

#include <qmessagebox.h>

#include "inifile.h"

IniFile::IniFile( QString filename )
{
	QFile file( filename );

	if ( file.open( IO_ReadOnly ) )
	{
		QString line;

		QStringList strlist;

		while( !file.atEnd() )
		{
			file.readLine( line, 1024 );
			line = line.stripWhiteSpace();
			if (line[0] == '#')
			{
				// This is a comment

				//cerr << "Comment:" << line << endl;
			}
			else
			{
				if ( !line.isEmpty() )
				{
					strlist.append( line );
				}
			}
		}

		QStringList temp;

		for (int i = strlist.count(); i > 0 ; i--)
		{
			if ( strlist[i-1].find("[") == -1 )
			{
				temp.prepend(strlist[i-1]);
			}
			else if ( strlist[i-1].find("[") == 0 )
			{
				temp.prepend(strlist[i-1]);
				sections.append( new IniSection( temp ) );
				temp.clear();
			}
		}
		file.close();
	}
	else
	{
		(void) QMessageBox::critical (0, "Fatal error", "It appears there is no .giFT directory in your home dir. \nThis could mean you did not run giFT-setup to setup giFT correctly,\nor if you want to connect to a remote giFT deamon use the -s switch", QMessageBox::Ok,  QMessageBox::NoButton);
		exit(1);
	}
}

IniFile::~IniFile()
{
}

IniSection* IniFile::getSection( QString name )
{
	QListIterator<IniSection> it (sections);
	IniSection *section;

	for (; it.current (); ++it)
	{
		section = it.current();
		if (section->name().compare( name ) == 0)
		{
			return section;
		}
	}
	return NULL;
}
